@@ -1,8 +1,8 @@
 // Empty leaves all features enabled.  See doc/html/features.html for choices.
+#ifndef QT_H
+#endif // QT_H
 
 // Note that disabling some features will produce a libqt that is not
 // compatible with other libqt builds. Such modifications are only
 // supported on Qt/Embedded where reducing the library size is important
 // and where the application-suite is often a fixed set.
-
-#define QT_NO_IMAGEIO_MNG // not defined by default.
